summaryrefslogtreecommitdiffstats
path: root/c/src/lib/libbsp/powerpc/shared/irq/openpic_i8259_irq.c
diff options
context:
space:
mode:
authorSebastian Huber <sebastian.huber@embedded-brains.de>2017-11-21 11:43:13 +0100
committerSebastian Huber <sebastian.huber@embedded-brains.de>2017-11-22 09:40:23 +0100
commit1c193a26d227a42a1ea76564950488f48189dbde (patch)
tree5818e3c47383605bd5fd78f80ceb0c9f9ce3cef8 /c/src/lib/libbsp/powerpc/shared/irq/openpic_i8259_irq.c
parentsapi: New implementation of rtems_panic() (diff)
downloadrtems-1c193a26d227a42a1ea76564950488f48189dbde.tar.bz2
powerpc: Replace BSP_panic() with rtems_panic()
Due to a new rtems_panic() implementation, it is possible to replace the PowerPC-specific BSP_panic() with rtems_panic(). Remove BSP_panic() implementations. Close #3245.
Diffstat (limited to '')
-rw-r--r--c/src/lib/libbsp/powerpc/shared/irq/openpic_i8259_irq.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/c/src/lib/libbsp/powerpc/shared/irq/openpic_i8259_irq.c b/c/src/lib/libbsp/powerpc/shared/irq/openpic_i8259_irq.c
index 80901223b8..4a9c393f7f 100644
--- a/c/src/lib/libbsp/powerpc/shared/irq/openpic_i8259_irq.c
+++ b/c/src/lib/libbsp/powerpc/shared/irq/openpic_i8259_irq.c
@@ -263,8 +263,8 @@ int C_dispatch_irq_handler (BSP_Exception_frame *frame, unsigned int excNum)
#error "Configuration Error -- BSP with ISA + PCI IRQs MUST define BSP_PCI_ISA_BRIDGE_IRQ"
#endif
#else
- BSP_panic("MUST have an OpenPIC if BSP has PCI IRQs but no ISA IRQs");
- /* BSP_panic() never returns but the 'return' statement silences
+ rtems_panic("MUST have an OpenPIC if BSP has PCI IRQs but no ISA IRQs");
+ /* rtems_panic() never returns but the 'return' statement silences
* a compiler warning about 'irq' possibly being used w/o initialization.
*/
return -1;